@@ -123,13 +123,15 @@ class ControlsPosition(StringListArgument):
 _classes = {
     "A-24": ("covmatic_stations.a.technogenetics", "StationATechnogenetics24", NumSamples),
     "A": ("covmatic_stations.a.technogenetics", "StationATechnogenetics48", NumSamples),
+    "A-Bioer": ("covmatic_stations.a.aBioerPreparation", "StationABioerPreparation"),
     "B": ("covmatic_stations.b.technogenetics", "StationBTechnogenetics", NumSamples),
     "B-Paired Pipette": ("covmatic_stations.b.technogenetics_paired_pipette", "StationBTechnogeneticsPairedPipette", NumSamples),
     "C": ("covmatic_stations.c.technogenetics", "StationCTechnogenetics", NumSamples),
     "Elution Removal": ("covmatic_stations.b.technogenetics_short", "StationBTechnogeneticsElutionRemoval", NumSamples, NumCycles),
     "Wash B Removal": ("covmatic_stations.b.technogenetics_short", "StationBTechnogeneticsWashBRemoval", NumSamples, NumCycles),
     "BioerPrep": ("covmatic_stations.bioer.Bioer_preparation", "BioerPreparation", NumSamples),
-    "BioerPCR": ("covmatic_stations.bioer.Bioer_full_dw", "BioerPreparationToPcr", NumSamples, ControlsPosition)
+    "BioerPCR": ("covmatic_stations.bioer.Bioer_full_dw", "BioerPreparationToPcr", NumSamples, ControlsPosition),
+    "BioerPCR-Technogenetics": ("covmatic_stations.bioer.Bioer_full_dw", "BioerPreparationToPcrTechogenetics", NumSamples, ControlsPosition)
 }
 
 
